@@ -1,6 +1,6 @@
-#' Get the interval of a datetime variable.
+#' Get the interval of a datetime variable
 #'
-#' The interval is the highest time unit that can explain all instances of a
+#' The interval is the highest datetime unit that can explain all instances of a
 #' variable of class \code{Date}, class \code{POSIXct}, or class \code{POSIXct}.
 #' This function will determine what the interval of the variable is.
 #' @param x A variable of class of class \code{Date} or of class \code{POSIXt}.
@@ -15,6 +15,7 @@
 #' get_interval(x_sec[seq(0, length(x_sec), by = 5)])
 #' @export
 get_interval <- function(x) {
+  stop_on_NA(x)
   interval <- get_interval_list(x)
   if (interval$step == 1) {
     return(interval$interval)
@@ -23,13 +24,16 @@ get_interval <- function(x) {
   }
 }
 
-get_interval_list <- function(x){
-  if ( !( inherits(x, 'Date') |  inherits(x, 'POSIXt')) ) {
-    stop('x should be of class Date, POSIXct, or POSIXlt.', call. = FALSE)
+stop_on_NA <- function(x) {
+  if (anyNA(x)) {
+    stop("interval cannot be determined when x contains NAs")
   }
+}
+
+get_interval_list <- function(x){
+  stop_not_datetime(x)
 
   x_char <- datetime_char(x)
-
   differ <- lowest_differ(x_char)
 
   if ( length(differ) == 0 ) {
@@ -50,14 +54,14 @@ get_interval_list <- function(x){
   return(list(interval = differ, step = step))
 }
 
-# change a variable of class Date or POSIXt to a character of length 18
-# as input for the differing
+# change a variable of class Date or POSIXt to a character, use format instead
+# of as.character for performance
 datetime_char <- function(x) {
-  x_char <- as.character(x)
-  if (unique(nchar(x_char)) == 10){
-    x_char <- paste(x_char, '00:00:00')
+  if (inherits(x, "Date")) {
+    paste(format(x, "%F"), "00:00:00")
+  } else {
+    format(x, "%F %T")
   }
-  return(x_char)
 }
 
 # check what levels of the datetime variable differ, x is the output of datetime_char
@@ -96,11 +100,11 @@ get_step <- function(x, d) {
   if (d == "year") return(step_of_year(x))
   if (d == "quarter") return(step_of_quarter(x))
   if (d == "month") return(step_of_month(x))
-  if (d == "week") return(step_with_difftime(x, "weeks"))
-  if (d == "day") return(step_with_difftime(x, "days"))
-  if (d == "hour") return(step_with_difftime(x, "hours"))
-  if (d == "min") return(step_with_difftime(x, "mins"))
-  if (d == "sec") return(step_with_difftime(x, "secs"))
+  if (d == "week") return(step_with_difftime(x, "week"))
+  if (d == "day") return(step_with_difftime(x, "day"))
+  if (d == "hour") return(step_with_difftime(x, "hour"))
+  if (d == "min") return(step_with_difftime(x, "min"))
+  if (d == "sec") return(step_with_difftime(x, "sec"))
 }
 
 step_of_year <- function(x) {
@@ -122,8 +126,12 @@ step_of_month <- function(x) {
   return( get_max_modulo_zero( get_difs(months), max_t = max_val) )
 }
 
-step_with_difftime <- function(x, units) {
-  time_dif <- as.numeric ( get_difftime(sort(x), units) )
+step_with_difftime <- function(x, unit) {
+  if (inherits(x, "Date")) {
+    time_dif <- numeric_dif_date(x, unit = unit)
+  } else if (inherits(x, "POSIXt")) {
+    time_dif <- numeric_dif_posix(x, unit = unit)
+  }
   return(get_max_modulo_zero( time_dif, max_t = smallest_nonzero(time_dif)) )
 }
 
@@ -154,12 +162,45 @@ get_max_modulo_zero <- function(d, min_t = 1, max_t = 60) {
   }
 }
 
-get_difftime <- function(x, units) {
-  n <- length(x)
-  difftime(x[2:n], x[1:(n - 1)], units = units)
-}
-
 smallest_nonzero <- function(x) {
   nonzero <- x[x > 0]
   min(nonzero)
 }
+
+# wrapper around get_interval that returns NA when interval can't be determined
+# instead of breaking.
+get_interval_try <- function(x) {
+  int <- try(get_interval(x), silent = TRUE)
+  if (inherits(int, "try-error")) {
+    int <- NA
+  }
+  int
+}
+
+## knowing the interval we can convert to numeric to get the units for
+## everything of a week and lower.
+numeric_dif_date <- function(x, unit) {
+  x_num <- sort(unique(as.numeric(x)))
+  difs  <- get_difs(x_num)
+  if (unit == "week") {
+    difs / 7
+  } else if (unit == "day") {
+    difs
+  }
+}
+
+numeric_dif_posix <- function(x, unit) {
+  x_num <- sort(unique(as.numeric(x)))
+  difs  <- get_difs(x_num)
+  if (unit == "sec") {
+    difs
+  } else if (unit == "min") {
+    difs / 60
+  } else if (unit == "hour") {
+    difs / 3600
+  } else if (unit == "day") {
+    difs / 86400
+  } else if (unit == "week") {
+    difs / 604800
+  }
+}
