@@ -1,4 +1,3 @@
-
 round_thicken <- function(a,
                           b,
                           direction = c('down', 'up')) {
@@ -9,12 +8,13 @@ round_thicken <- function(a,
   b_same_level <- to_posix(a, b)$b
 
   a_df <- data.frame(a_same_level = a_same_level,
-                     sorting_var = 1:length(a))
-  a_df <- a_df[order(a_df$a), ]
+                     sorting_var = seq_along(a))
+  a_df <- dplyr::arrange(a_df, a)
   b_same_level <- sort(b_same_level)
 
   a_df$rounded <- apply_rounding(a_df$a_same_level, b_same_level, direction)
-  a_df <- a_df[order(a_df$sorting_var), ]
+  sorting_var  <- NULL # appeases CRAN check note
+  a_df <- dplyr::arrange(a_df, sorting_var)
   rounded <- a_df$rounded
 
   if (inherits(a_same_level, 'Date')){
@@ -24,7 +24,6 @@ round_thicken <- function(a,
                             tz = attr(a_same_level, 'tz'))
   }
   thickened <- posix_to_date(thickened)
-
   return(thickened)
 }
 
@@ -68,9 +67,11 @@ apply_rounding <- function(a, b,  direction = c('up', 'down')) {
 # well can be of class Date
 posix_to_date <- function(x) {
   if ( inherits(x, 'POSIXt')) {
-  check_var <- as.POSIXlt(x)
-  to_date <- all( c(check_var$hour, check_var$min, check_var$sec ) == 0 )
-  if (to_date) x <- as.Date(x, tz = attr(x, 'tzone'))
+    check_var <- as.POSIXlt(x)
+    to_date <- all( c(check_var$hour, check_var$min, check_var$sec ) == 0 )
+    if (to_date) {
+      x <- as.Date(x, tz = lubridate::tz(x))
+    }
   }
   return(x)
 }
